StringEq

Macro StringEq 

StringEq!() { /* proc-macro */ }
Expands a string literal into a type-level literal token.

This is the primary way to create literal tokens — the underlying StringEq<CharThen<CH, T>> type is an implementation detail and should not be named directly.

  • Single character: StringEq!(",")StringEq<CharThen<',', ()>>
  • Multiple characters: StringEq!("->")StringEq<CharThen<'-', CharThen<'>', ()>>>